==> sh40_slate-0.5.0.tar.gz: sh40_slate-0.5.0/slate/key_names.py <==
"""Dictionaries of key translations, used by `getch` and friends."""

POSIX_KEY_NAMES = {  # pylint: disable=cyclic-import
    "\x1b[A": ("up",),
    "\x1b[B": ("down",),
    "\x1b[C": ("right",),
    "\x1b[D": ("left",),
    "\x1b[1;2A": ("shift-up",),
    "\x1b[1;2B": ("shift-down",),
    "\x1b[1;2C": ("shift-right",),
    "\x1b[1;2D": ("shift-left",),
    "\x1b[1;3A": ("alt-up",),
    "\x1b[1;3B": ("alt-down",),
    "\x1b[1;3C": ("alt-right",),
    "\x1b[1;3D": ("alt-left",),
    "\x1b[1;4A": ("alt-shift-up",),
    "\x1b[1;4B": ("alt-shift-down",),
    "\x1b[1;4C": ("alt-shift-right",),
    "\x1b[1;4D": ("alt-shift-left",),
    "\x7f": ("backspace",),
    "\b": ("alt-backspace",),
    "\x1b\x7f": ("ctrl-backspace",),
    "\x01": ("ctrl-a",),
    "\x02": ("ctrl-b",),
    "\x03": ("ctrl-c",),
    "\x04": ("ctrl-d",),
    "\x05": ("ctrl-e",),
    "\x06": ("ctrl-f",),
    "\x07": ("ctrl-g",),
    "\x08": ("ctrl-h",),
    "\t": (
        "tab",
        "ctrl-i",
    ),
    "\n": (
        "return",
        "ctrl-j",
    ),
    "\x0b": ("ctrl-k",),
    "\x0c": ("ctrl-l",),
    "\r": ("ctrl-m",),
    "\x0e": ("ctrl-n",),
    "\x0f": ("ctrl-o",),
    "\x10": ("ctrl-p",),
    "\x11": ("ctrl-q",),
    "\x12": ("ctrl-r",),
    "\x13": ("ctrl-s",),
    "\x14": ("ctrl-t",),
    "\x15": ("ctrl-u",),
    "\x16": ("ctrl-v",),
    "\x17": ("ctrl-w",),
    "\x18": ("ctrl-x",),
    "\x19": ("ctrl-y",),
    "\x1a": ("ctrl-z",),
    "\x1b[1;5A": ("ctrl-up",),
    "\x1b[1;5B": ("ctrl-down",),
    "\x1b[1;5C": ("ctrl-right",),
    "\x1b[1;5D": ("ctrl-left",),
    "\x1b[H": ("end",),
    "\x1b[F": ("home",),
    "\x1b[2~": ("insert",),
    "\x1b[3~": ("delete",),
    "\x1b[Z": ("shift-tab",),
    "\x1b[11~": ("F1",),
    "\x1b[12~": ("F2",),
    "\x1b[13~": ("F3",),
    "\x1b[14~": ("F4",),
    "\x1b[15~": ("F5",),
    "\x1b[17~": ("F6",),
    "\x1b[18~": ("F7",),
    "\x1b[19~": ("F8",),
    "\x1b[20~": ("F9",),
    "\x1b[21~": ("F10",),
    "\x1b[23~": ("F11",),
    "\x1b[24~": ("F12",),
}

NT_KEY_NAMES = {
    "\x1b": ("esc",),
    "\x1bK": ("left",),
    "\x1bM": ("right",),
    "\x1bH": ("up",),
    "\x1bP": ("down",),
    "\r": ("return",),
    "\x08": ("backspace",),
    "\x00;": ("f1",),
    "\x00<": ("f2",),
    "\x00=": ("f3",),
    "\x00>": ("f4",),
    "\x00?": ("f5",),
    "\x00@": ("f6",),
    "\x00A": ("f7",),
    "\x00B": ("f8",),
    "\x00C": ("f9",),
    "\x00D": ("f10",),
    "\xe0\x85": ("f11",),
    "\xe0\x86": ("f12",),
}

==> sh40_slate-0.5.1.tar.gz: sh40_slate-0.5.1/slate/key_names.py <==
"""Dictionaries of key translations, used by `getch` and friends."""

POSIX_KEY_NAMES = {  # pylint: disable=cyclic-import
    "\x1b[A": ("up",),
    "\x1b[B": ("down",),
    "\x1b[C": ("right",),
    "\x1b[D": ("left",),
    "\x1b[1;2A": ("shift-up",),
    "\x1b[1;2B": ("shift-down",),
    "\x1b[1;2C": ("shift-right",),
    "\x1b[1;2D": ("shift-left",),
    "\x1b[1;3A": ("alt-up",),
    "\x1b[1;3B": ("alt-down",),
    "\x1b[1;3C": ("alt-right",),
    "\x1b[1;3D": ("alt-left",),
    "\x1b[1;4A": ("alt-shift-up",),
    "\x1b[1;4B": ("alt-shift-down",),
    "\x1b[1;4C": ("alt-shift-right",),
    "\x1b[1;4D": ("alt-shift-left",),
    "\x7f": ("backspace",),
    "\x1b\x7f": ("alt-backspace",),
    "\x01": ("ctrl-a",),
    "\x02": ("ctrl-b",),
    "\x03": ("ctrl-c",),
    "\x04": ("ctrl-d",),
    "\x05": ("ctrl-e",),
    "\x06": ("ctrl-f",),
    "\x07": ("ctrl-g",),
    "\x08": (
        "ctrl-backspace",
        "ctrl-h",
    ),
    "\t": (
        "tab",
        "ctrl-i",
    ),
    "\n": (
        "return",
        "ctrl-j",
    ),
    "\x0b": ("ctrl-k",),
    "\x0c": ("ctrl-l",),
    "\r": ("ctrl-m",),
    "\x0e": ("ctrl-n",),
    "\x0f": ("ctrl-o",),
    "\x10": ("ctrl-p",),
    "\x11": ("ctrl-q",),
    "\x12": ("ctrl-r",),
    "\x13": ("ctrl-s",),
    "\x14": ("ctrl-t",),
    "\x15": ("ctrl-u",),
    "\x16": ("ctrl-v",),
    "\x17": ("ctrl-w",),
    "\x18": ("ctrl-x",),
    "\x19": ("ctrl-y",),
    "\x1a": ("ctrl-z",),
    "\x1b[1;5A": ("ctrl-up",),
    "\x1b[1;5B": ("ctrl-down",),
    "\x1b[1;5C": ("ctrl-right",),
    "\x1b[1;5D": ("ctrl-left",),
    "\x1b[H": ("end",),
    "\x1b[F": ("home",),
    "\x1b[2~": ("insert",),
    "\x1b[3~": ("delete",),
    "\x1b[Z": ("shift-tab",),
    "\x1b[11~": ("F1",),
    "\x1b[12~": ("F2",),
    "\x1b[13~": ("F3",),
    "\x1b[14~": ("F4",),
    "\x1b[15~": ("F5",),
    "\x1b[17~": ("F6",),
    "\x1b[18~": ("F7",),
    "\x1b[19~": ("F8",),
    "\x1b[20~": ("F9",),
    "\x1b[21~": ("F10",),
    "\x1b[23~": ("F11",),
    "\x1b[24~": ("F12",),
}

NT_KEY_NAMES = {
    "\x1b": ("esc",),
    "\x1bK": ("left",),
    "\x1bM": ("right",),
    "\x1bH": ("up",),
    "\x1bP": ("down",),
    "\r": ("return",),
    "\x08": ("backspace",),
    "\x00;": ("f1",),
    "\x00<": ("f2",),
    "\x00=": ("f3",),
    "\x00>": ("f4",),
    "\x00?": ("f5",),
    "\x00@": ("f6",),
    "\x00A": ("f7",),
    "\x00B": ("f8",),
    "\x00C": ("f9",),
    "\x00D": ("f10",),
    "\xe0\x85": ("f11",),
    "\xe0\x86": ("f12",),
}
